@@ -50,6 +50,8 @@ import vigranumpytest as vt
 from nose.tools import assert_equal, raises, assert_true
 
 from vigra.arraytypes import AxisTags, AxisInfo
+import platform
+IS_PYPY = platform.python_implementation() == 'PyPy'
 
 if sys.version_info[0] > 2:
     def xrange(*args):
@@ -94,7 +96,8 @@ def computeVStrides(shape, hasChannelAxis):
 def checkArray(cls, channels, dim, hasChannelAxis=True):
         def testCopy(img):
             b = cls(img, order='A')
-            assert_equal(sys.getrefcount(b), 2)
+            if not IS_PYPY:
+                assert_equal(sys.getrefcount(b), 2)
             assert b.__class__ is img.__class__
             assert_equal(b.shape, img.shape)
             assert_equal(b.strides, img.strides)
@@ -104,7 +107,8 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
             assert (b == img).all()
             assert not numpy.may_share_memory(b, img)
             b = img.copy(order='A')
-            assert_equal(sys.getrefcount(b), 2)
+            if not IS_PYPY:
+                assert_equal(sys.getrefcount(b), 2)
             assert_equal(b.shape, img.shape)
             assert_equal(b.strides, img.strides)
             assert_equal(b.order, img.order)
@@ -145,7 +149,8 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
 #        assert type(img) is cls
         assert isinstance(img, numpy.ndarray)
         assert_equal(img.dtype, numpy.float32)
-        assert_equal(sys.getrefcount(img), 2)
+        if not IS_PYPY:
+            assert_equal(sys.getrefcount(img), 2)
 
         # test shape
         checkShape(img.shape, vshape)
@@ -211,7 +216,8 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
 
         # test shape, strides, and copy for 'F' order
         img = cls(fshape, order='F')
-        assert_equal(sys.getrefcount(img), 2)
+        if not IS_PYPY:
+            assert_equal(sys.getrefcount(img), 2)
         checkShape(img.shape, fshape)
         checkStride(img.strides, ffstrides)
         assert_equal(img.axistags, faxistags)
@@ -241,7 +247,8 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
 
         # test shape, strides, and copy for 'A' order (should be equal to 'V' order)
         img = cls(vshape, order='A')
-        assert_equal(sys.getrefcount(img), 2)
+        if not IS_PYPY:
+            assert_equal(sys.getrefcount(img), 2)
         checkShape(img.shape, vshape)
         checkStride(img.strides, fvstrides)
         if channels > 1:
@@ -261,7 +268,8 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
 
         # test shape, strides, and copy for 'C' order
         img = cls(cshape, order='C')
-        assert_equal(sys.getrefcount(img), 2)
+        if not IS_PYPY:
+            assert_equal(sys.getrefcount(img), 2)
         checkShape(img.shape, cshape)
         checkStride(img.strides, fcstrides)
         assert_equal(img.axistags, caxistags)
@@ -292,7 +300,8 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
         # test shape, strides, and copy for dtype uint8
         img = cls(vshape, order="V")
         b = cls(img, dtype=numpy.uint8, order='V')
-        assert_equal(sys.getrefcount(b), 2)
+        if not IS_PYPY:
+            assert_equal(sys.getrefcount(b), 2)
         assert_equal(b.dtype, numpy.uint8)
         checkShape(b.shape, img.shape)
         checkStride(b.strides, computeVStrides(b.shape, hasChannelAxis))
@@ -315,7 +324,8 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
 
         img = cls(cshape, order="C")
         b = cls(img, dtype=numpy.uint8, order='C')
-        assert_equal(sys.getrefcount(b), 2)
+        if not IS_PYPY:
+            assert_equal(sys.getrefcount(b), 2)
         checkShape(b.shape, img.shape)
         checkStride(b.strides, computeCStrides(b.shape))
         assert_equal(b.axistags, img.axistags)
@@ -332,7 +342,8 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
 
         img = cls(fshape, order="F")
         b = cls(img, dtype=numpy.uint8, order='F')
-        assert_equal(sys.getrefcount(b), 2)
+        if not IS_PYPY:
+            assert_equal(sys.getrefcount(b), 2)
         checkShape(b.shape, img.shape)
         checkStride(b.strides, computeFStrides(b.shape))
         assert_equal(b.axistags, img.axistags)
@@ -1531,7 +1542,7 @@ def testMethods():
     assert_equal(b.axistags, a.axistags)
 
 def testUfuncs():
-    from numpy import bool, int8, uint8, int16, uint16, int32, uint32, int64, uint64
+    from numpy import bool_, int8, uint8, int16, uint16, int32, uint32, int64, uint64
     from numpy import float32, float64, longdouble, complex64, complex128, clongdouble
     integers = [ int8, uint8, int16, uint16, int32, uint32, int64, uint64]
     floats = [float32, float64, longdouble]
@@ -1553,7 +1564,7 @@ def testUfuncs():
         assert_equal(a.axistags, b.axistags)
         assert (b == t(4)).all()
         b = a == a
-        assert_equal(bool, b.dtype)
+        assert_equal(bool_, b.dtype)
         assert_equal(a.axistags, b.axistags)
         assert (b == True).all()
         b = ones[t] + a
@@ -1588,7 +1599,7 @@ def testUfuncs():
             assert_equal(a1.axistags, b.axistags)
             assert (b == 4).all()
             b = a1 <= a2
-            assert_equal(bool, b.dtype)
+            assert_equal(bool_, b.dtype)
             assert_equal(a1.axistags, b.axistags)
             assert (b == True).all()
         for j in floats + compl:
@@ -1602,11 +1613,11 @@ def testUfuncs():
             assert_equal(a1.axistags, b.axistags)
             assert (b == 4).all()
             b = a1 >= a2
-            assert_equal(bool, b.dtype)
+            assert_equal(bool_, b.dtype)
             assert_equal(a1.axistags, b.axistags)
             assert (b == True).all()
             b = a2 > a1
-            assert_equal(bool, b.dtype)
+            assert_equal(bool_, b.dtype)
             assert_equal(a1.axistags, b.axistags)
             assert (b == False).all()
         b = a1 + 1
@@ -1635,11 +1646,11 @@ def testUfuncs():
             assert_equal(a1.axistags, b.axistags)
             assert (b == 4).all()
             b = a1 >= a2
-            assert_equal(bool, b.dtype)
+            assert_equal(bool_, b.dtype)
             assert_equal(a1.axistags, b.axistags)
             assert (b == True).all()
             b = a2 > a1
-            assert_equal(bool, b.dtype)
+            assert_equal(bool_, b.dtype)
             assert_equal(a1.axistags, b.axistags)
             assert (b == False).all()
         b = a1 + 0.5
